<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Feature_Box extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Feature box', 'interico' ), // Name
			array(
				'description' => __( 'Feature Box with an Icon', 'interico' ) // Description
			)
		);
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {
		echo $args['before_widget'];

		if ( isset( $instance['icon_box_style'] ) ) {
			$icon_box_style = $instance['icon_box_style'];
		} else {
			$icon_box_style = 'default';
		}

		if ( isset( $instance['feaure_box_color'] ) ) {
			$feaure_box_color = $instance['feaure_box_color'];
		} else {
			$feaure_box_color = 'default';
		}

		if ( isset( $instance['icon_layout'] ) ) {
			$icon_layout = $instance['icon_layout'];
		} else {
			$icon_layout = 'large-left';
		}

		?>

		<!-- Begin Feature box -->
		<?php if( esc_url( $instance['feature_link'] ) ) : ?>
			<a href="<?php echo esc_url( $instance['feature_link'] ); ?>">
		<?php endif; ?>

			<div class="feature-box icon-<?php echo esc_attr( $icon_layout ); ?> box-<?php echo esc_attr( $icon_box_style ); ?> <?php echo esc_attr( $feaure_box_color ); ?>">

				<?php if( esc_attr( $instance['linear_icon'] ) ) : ?>
					<span class="lnr <?php echo esc_attr( $instance['linear_icon'] ); ?>"></span>
				<?php elseif( esc_attr( $instance['feature_icon'] ) ) : ?>
					<i class="fa <?php echo esc_attr( $instance['feature_icon'] ); ?>"></i>
				<?php endif; ?>

				<div class="content-wrapper">

					<?php if( esc_attr( $instance['feature_title'] ) ) : ?>
						<h3 class="feature-title"><?php echo esc_attr( $instance['feature_title'] ); ?></h3>
					<?php endif; ?>

					<?php if( esc_attr( $instance['feature_text'] ) && ( 'title-only' !== $icon_layout ) ) : ?>
						<p class="feature-text"><?php echo esc_attr( $instance['feature_text'] ); ?></p>
					<?php endif; ?>

					<?php if( esc_attr( $instance['feature_link_text'] ) && ( 'title-only' !== $icon_layout ) ) : ?>
						<div class="btn-read-more"><?php echo esc_attr( $instance['feature_link_text'] ); ?></div>
					<?php endif; ?>

				</div>

			</div>

		<?php if( esc_url( $instance['feature_link'] ) ) : ?>
			</a>
		<?php endif; ?>
		<!-- End Feature box -->

		<?php
		echo $args['after_widget'];
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['feature_link'] 	   = sanitize_text_field( $new_instance['feature_link'] );
		$instance['feature_icon'] 	   = sanitize_html_class( $new_instance['feature_icon'] );
		$instance['linear_icon'] 	   = sanitize_html_class( $new_instance['linear_icon'] );
		$instance['feature_title'] 	   = wp_kses_post( $new_instance['feature_title'] );
		$instance['feature_text']	   = wp_kses_post( $new_instance['feature_text'] );
		$instance['feature_link_text'] = wp_kses_post( $new_instance['feature_link_text'] );
		$instance['icon_box_style']	   = wp_kses_post( $new_instance['icon_box_style'] );
		$instance['icon_layout']	   = wp_kses_post( $new_instance['icon_layout'] );
		$instance['feaure_box_color']  = wp_kses_post( $new_instance['feaure_box_color'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	 public function form( $instance ) {
	 	$feature_link  		= empty( $instance['feature_link'] ) ? '' : $instance['feature_link'];
	 	$feature_icon   	= empty( $instance['feature_icon'] ) ? '' : $instance['feature_icon'];
	 	$linear_icon   		= empty( $instance['linear_icon'] ) ? '' : $instance['linear_icon'];
	 	$feature_title  	= empty( $instance['feature_title'] ) ? '' : $instance['feature_title'];
	 	$feature_text   	= empty( $instance['feature_text'] ) ? '' : $instance['feature_text'];
	 	$feature_link_text  = empty( $instance['feature_link_text'] ) ? '' : $instance['feature_link_text'];
	 	$icon_box_style  	= empty( $instance['icon_box_style'] ) ? '' : $instance['icon_box_style'];
	 	$icon_layout 	 	= empty( $instance['icon_layout'] ) ? '' : $instance['icon_layout'];
	 	$feaure_box_color 	= empty( $instance['feaure_box_color'] ) ? '' : $instance['feaure_box_color'];

	 	?>

	 	<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'icon_layout' ) ); ?>"><?php esc_html_e( 'Select Feature Box Layout:', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'icon_layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'icon_layout' ) ); ?>">
				<option value="large-left" <?php selected( $icon_layout, 'large-left' ); ?>><?php esc_html_e( 'Icon left', 'interico' ); ?></option>
				<option value="top-centered" <?php selected( $icon_layout, 'top-centered' ); ?>><?php esc_html_e( 'Icon Top Cenetered', 'interico' ); ?></option>
				<option value="top-left" <?php selected( $icon_layout, 'top-left' ); ?>><?php esc_html_e( 'Icon Top Left', 'interico' ); ?></option>
				<option value="title-only" <?php selected( $icon_layout, 'title-only' ); ?>><?php esc_html_e( 'Icon & Title Only, Vertically centered', 'interico' ); ?></option>
				<option value="title-only slim" <?php selected( $icon_layout, 'title-only slim' ); ?>><?php esc_html_e( 'Icon & Title Slim', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'icon_box_style' ) ); ?>"><?php esc_html_e( 'Select Feature Box Style', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'icon_box_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'icon_box_style' ) ); ?>">
				<option value="default" <?php selected( $icon_box_style, 'default' ); ?>><?php esc_html_e( 'Default Boxed', 'interico' ); ?></option>
				<option value="hovered" <?php selected( $icon_box_style, 'hovered' ); ?>><?php esc_html_e( 'Boxed Hovered', 'interico' ); ?></option>
				<option value="unboxed" <?php selected( $icon_box_style, 'unboxed' ); ?>><?php esc_html_e( 'Unboxed', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'feaure_box_color' ) ); ?>"><?php esc_html_e( 'Select Feature Box Color Scheme', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'feaure_box_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feaure_box_color' ) ); ?>">
				<option value="default" <?php selected( $feaure_box_color, 'default' ); ?>><?php esc_html_e( 'Style 1: Light', 'interico' ); ?></option>
				<option value="dark" <?php selected( $feaure_box_color, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark', 'interico' ); ?></option>
			</select>
		</p>

		

		<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'linear_icon' ) ); ?>"><?php esc_html_e( 'Linearicon Icon', 'interico' ); ?></label><br/><small><em><?php printf( esc_html__( 'See %s for all icon classes (example: lnr-home)', 'interico' ), '<a href="'. esc_url( 'https://linearicons.com/free' ) . '" target="_blank">Linearicons</a>' ); ?></em></small></label> <br />
	 		<input type="text" name="<?php echo esc_attr( $this->get_field_name( 'linear_icon' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'linear_icon' ) ); ?>" value="<?php echo esc_attr( $linear_icon ); ?>" />
	 	</p>

	 	<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'feature_icon' ) ); ?>"><?php esc_html_e( 'FontAwesome Icon', 'interico' ); ?></label><br/><small><em><?php printf( esc_html__( 'See %s for all icon classes (example: fa-home)', 'interico' ), '<a href="'. esc_url( 'https://fontawesome.com/v4.7.0/icons/' ) . '" target="_blank">FontAwesome</a>' ); ?></em></small></label> <br />
	 		<input type="text" name="<?php echo esc_attr( $this->get_field_name( 'feature_icon' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'feature_icon' ) ); ?>" value="<?php echo esc_attr( $feature_icon ); ?>" />
	 	</p>

	 	<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'feature_title' ) ); ?>"><?php esc_html_e( 'Feature Title', 'interico' ); ?>:</label> <br />
	 		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_title' ) ); ?>" type="text" value="<?php echo esc_attr( $feature_title ); ?>" />
	 	</p>

	 	<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'feature_text' ) ); ?>"><?php esc_html_e( 'Feature Text', 'interico' ); ?>:</label> <br />
	 		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_text' ) ); ?>" type="text" value="<?php echo esc_attr( $feature_text ); ?>" />
	 	</p>

	 	<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'feature_link_text' ) ); ?>"><?php esc_html_e( 'Feature Link Text', 'interico' ); ?>:</label> <br />
	 		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_link_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_link_text' ) ); ?>" type="text" value="<?php echo esc_attr( $feature_link_text ); ?>" />
	 	</p>

	 	<p>
	 		<label for="<?php echo esc_attr( $this->get_field_id( 'feature_link' ) ); ?>"><?php esc_html_e( 'Link (Optional)', 'interico' ); ?>:</label> <br />
	 		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_link' ) ); ?>" type="text" value="<?php echo esc_url( $feature_link ); ?>" />
	 	</p>
	 	
	 	<?php
	 }
}

add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Feature_Box" );' ) );
