<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Number_Box extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Number Box', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Display numbered items: Process, Services, Stats', 'interico' ) // Description
			)
		);		
	}


	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {
		
		$number_box_number  = $instance['number_box_number'];
		$number_box_title   = $instance['number_box_title'];
		$number_box_content = $instance['number_box_content'];
		$number_link     	= $instance['number_link'];
		$number_link_text   = $instance['number_link_text'];

		// Set number box style
		if ( isset( $instance['number_box_style'] ) ) {
			$number_box_style = $instance['number_box_style'];
		} else {
			// If empty, use default style
			$number_box_style = 'default';
		}

		echo $args['before_widget'];
		?>

		<!-- Begin number box -->
		<div class="number-box style-<?php echo esc_attr( $number_box_style ); ?>">

			<?php if( esc_url( $number_link ) ) : ?>
				<a href="<?php echo esc_url( $number_link ); ?>">
			<?php endif; ?>
				<?php if ( esc_attr( $number_box_number ) ) : ?>
					<div class="number-box-number"><?php echo esc_attr( $number_box_number ); ?></div>
				<?php endif; ?>
				<div class="content-box">
					<div class="content-box-info">
						<?php if ( esc_attr( $number_box_title ) ) : ?>
							<h3><?php echo esc_attr( $number_box_title ); ?></h3>
						<?php endif; ?>
						<?php if( esc_attr( $number_box_content ) ) : ?>
							<p class="number-box-content"><?php echo esc_attr( $number_box_content ); ?></p>
						<?php endif; ?>
						<?php if( esc_url( $number_link_text ) ) : ?>
							<div class="btn-read-more"><?php echo esc_attr( $number_link_text ); ?></div>
						<?php endif; ?>
					</div>
				</div>
			<?php if( esc_url( $number_link ) ) : ?>
				</a>
			<?php endif; ?>
		</div>
		<!-- End number box -->

		<?php
		echo $args['after_widget'];
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['number_box_number']	= wp_kses_post( $new_instance['number_box_number'] );
		$instance['number_box_title']	= wp_kses_post( $new_instance['number_box_title'] );
		$instance['number_box_content']	= wp_kses_post( $new_instance['number_box_content'] );
		$instance['number_link']		= sanitize_text_field( $new_instance['number_link'] );
		$instance['number_link_text']	= wp_kses_post( $new_instance['number_link_text'] );
		$instance['number_box_style']	= wp_kses_post( $new_instance['number_box_style'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {

		$number_box_number  = empty( $instance['number_box_number'] ) ? '' : $instance['number_box_number'];
		$number_box_title   = empty( $instance['number_box_title'] ) ? '' : $instance['number_box_title'];
		$number_box_content = empty( $instance['number_box_content'] ) ? '' : $instance['number_box_content'];
		$number_link     	= empty( $instance['number_link'] ) ? '' : $instance['number_link'];
		$number_link_text   = empty( $instance['number_link_text'] ) ? '' : $instance['number_link_text'];
		$number_box_style  	= empty( $instance['number_box_style'] ) ? '' : $instance['number_box_style'];

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_box_number' ) ); ?>"><?php esc_html_e( 'Large Number', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_box_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_box_number' ) ); ?>" type="text" value="<?php echo esc_attr( $number_box_number ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_box_title' ) ); ?>"><?php esc_html_e( 'Heading', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_box_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_box_title' ) ); ?>" type="text" value="<?php echo esc_attr( $number_box_title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_box_content' ) ); ?>"><?php esc_html_e( 'Content (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_box_content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_box_content' ) ); ?>" type="text" value="<?php echo esc_attr( $number_box_content ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_link_text' ) ); ?>"><?php esc_html_e( 'Link Text (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_link_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_link_text' ) ); ?>" type="text" value="<?php echo esc_attr( $number_link_text ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_link' ) ); ?>"><?php esc_html_e( 'Link URL (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_link' ) ); ?>" type="text" value="<?php echo esc_url( $number_link ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number_box_style' ) ); ?>"><?php esc_html_e( 'Style & Color Scheme', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'number_box_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_box_style' ) ); ?>">
				<option value="default" <?php selected( $number_box_style, 'default' ); ?>><?php esc_html_e( 'Style 1', 'interico' ); ?></option>
				<option value="default dark" <?php selected( $number_box_style, 'default dark' ); ?>><?php esc_html_e( 'Style 1 (Dark)', 'interico' ); ?></option>
				<option value="dark" <?php selected( $number_box_style, 'dark' ); ?>><?php esc_html_e( 'Style 2', 'interico' ); ?></option>
				<option value="dark dark" <?php selected( $number_box_style, 'dark dark' ); ?>><?php esc_html_e( 'Style 2 (Dark)', 'interico' ); ?></option>
			</select>
		</p>
		
		<?php
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Number_Box" );' ) );
