<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Projects_Gallery_Single extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Projects Gallery Single Category', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Insert Projects Gallery to Display One Category', 'interico' ) // Description
			)
		);
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['title'] 				   = wp_kses_post( $new_instance['title'] );
		$instance['page_id'] 			   = absint( $new_instance['page_id'] );
		$instance['gallery_button_text']   = wp_kses_post( $new_instance['gallery_button_text'] );
		$instance['gallery_rows_count']    = absint( $new_instance['gallery_rows_count'] );
		$instance['gallery_columns_count'] = absint( $new_instance['gallery_columns_count'] );
		$instance['category'] 			   = absint( $new_instance['category'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {

		$title  			   = empty( $instance['title'] ) ? '' : $instance['title'];
		$page_id			   = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$gallery_button_text   = empty( $instance['gallery_button_text'] ) ? '' : $instance['gallery_button_text'];
		$gallery_rows_count    = empty( $instance['gallery_rows_count'] ) ? 2 : (int) $instance['gallery_rows_count'];
		$gallery_columns_count = empty( $instance['gallery_columns_count'] ) ? 3 : (int) $instance['gallery_columns_count'];
		$category		   	   = empty( $instance['category'] ) ? '' : $instance['category'];
		
		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Set Title (Optional):', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Select Projects Category to Display:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_categories(
					array(
						'post_type'       => 'portfolio', // filter by the post type 'portfolio'
						'taxonomy'        => 'portfolio_category',
						'value_field'	  => 'term_id',
						'selected' 		  => $category,
						'name'     		  => $this->get_field_name( 'category' ),
						'show_option_all' => esc_html__( 'All categories', 'interico'  ),
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_columns_count' ) ); ?>"><?php esc_html_e( 'Number of Columns (2, 3, 4 or 6;)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_columns_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_columns_count' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_columns_count ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_rows_count' ) ); ?>"><?php esc_html_e( 'Number of Rows', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_rows_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_rows_count' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_rows_count ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_button_text' ) ); ?>"><?php esc_html_e( 'Gallery Button Text (Leave empty to hide)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_button_text ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Gallery Button Link:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>
		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {

		echo $args['before_widget'];

		// Set link text
		if ( isset( $instance['gallery_button_text'] ) ) {
			$gallery_button_text = $instance['gallery_button_text'];
		} else {
			$gallery_button_text = false;
		}

		$tc_gallery_color_scheme = get_theme_mod( 'tc_gallery_color_scheme' );

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Set rows count
		if ( isset( $instance['gallery_rows_count'] ) ) {
			$gallery_rows_count = $instance['gallery_rows_count'];
			if ( $gallery_rows_count === 0 ) {
				$gallery_rows_count = 2;
			}
		} else {
			$gallery_rows_count = 2;
		}

		// Set columns count
		if ( isset( $instance['gallery_columns_count'] ) ) {
			$gallery_columns_count = $instance['gallery_columns_count'];
			if ( $gallery_columns_count === 0 ) {
				$gallery_columns_count = 3;
			}
		} else {
			$gallery_columns_count = 3;
		}

		$gallery_column_width = 12/$gallery_columns_count;

		$gallery_items_count = $gallery_rows_count*$gallery_columns_count;

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );

		if ( isset( $instance['category'] ) ) {
			$gallery_category = $instance['category'];
		}
		
		$projects_query = new WP_Query(
			array(
				'post_type' 	 => 'portfolio',
				'posts_per_page' => $gallery_items_count,
				'cat' 			 	  => $gallery_category,
			)
		);

		?>

		<!-- Begin Latest Projects -->
		<section class="section-gallery<?php echo 'light' === esc_attr( $tc_gallery_color_scheme ) ? ' ' . 'gallery-light' : '' ?>">
			<?php if( esc_attr( $instance['title'] ) ) : ?>
				<h2 class="section-title mrg-btm"><?php echo esc_attr( $instance['title'] ); ?></h2>
			<?php endif; ?>
			<div class="wow fadeInUp" id="gallery">
				<div class="container-fluid">
					<div class="row no-gutter">

						<!-- Display the projects -->

						<?php
							if ( $projects_query->have_posts() ) :
								while ( $projects_query->have_posts() ) : $projects_query->the_post();
								
								$project_id = get_the_ID();
								$project = (array)get_post( $project_id );

								// Prepare Featured Image srcset
								$project_image_id     = get_post_thumbnail_id();
								$project_image_data   = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-l' );
								$sizes 		  		  = array( 'interico-portfolio-xs', 'interico-portfolio-s', 'interico-portfolio-ml', 'interico-portfolio-xl', );
								$project['image_url'] = $project_image_data[0];

								$termsArray = get_the_terms( $project['ID'], 'portfolio_category' );  // Get the terms for this particular item
								$termsString = ""; // initialize the string that will contain the terms
								foreach ( $termsArray as $term ) { // for each term:
									$termsString .= $term->slug . ' '; // create a string that has all the slugs 
								}
						?>
						
							<!-- Begin project item -->
							<div class="col-xs-12 col-sm-6 col-lg-<?php echo esc_attr( $gallery_column_width ); ?> item <?php echo esc_attr( $termsString ); ?>">
								<a href="<?php esc_url( the_permalink() ); ?>" class="portfolio-box">
									<img src="<?php echo esc_url( $project['image_url'] ); ?>" width="<?php echo esc_attr( $project_image_data[1] ); ?>" height="<?php echo esc_attr( $project_image_data[2] ); ?>" alt="<?php echo esc_attr( $project['post_title'] ); ?>">
									<div class="portfolio-box-caption">
										<div class="portfolio-box-caption-content">
											<div class="project-category text-faded">
												<?php echo esc_attr( $termsString ); ?>
											</div>
											<div class="project-name">
												<?php echo esc_attr( $project['post_title'] ); ?>
											</div>
										</div>
									</div>
								</a>
							</div> <!-- End project item -->
						
							<?php endwhile;
							wp_reset_postdata();
						endif; ?>

					</div> <!-- End row -->
				</div> <!-- End container -->
			</div> <!-- End #gallery -->

			<?php if( esc_attr( $instance['gallery_button_text'] ) ) : ?>
				<a href="<?php echo esc_url( $page['url'] ); ?>" class="btn-all-projects"><?php printf( esc_html__( '%s', 'interico' ), $gallery_button_text ); ?></a>
			<?php endif; ?>		
		</section> <!-- End Content section -->    

		<?php
		echo $args['after_widget'];
	}

}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Projects_Gallery_Single" );' ) );