<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Projects_Gallery extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Projects Gallery', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Insert Projects Gallery', 'interico' ) // Description
			)
		);
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['title'] 				    = wp_kses_post( $new_instance['title'] );
		$instance['page_id'] 			    = absint( $new_instance['page_id'] );
		$instance['gallery_button_text']    = wp_kses_post( $new_instance['gallery_button_text'] );
		$instance['gallery_rows_count']     = absint( $new_instance['gallery_rows_count'] );
		$instance['gallery_columns_count']  = absint( $new_instance['gallery_columns_count'] );
		$instance['show_gallery_filters']   = wp_kses_post( $new_instance['show_gallery_filters'] );
		$instance['gallery_style']			= wp_kses_post( $new_instance['gallery_style'] );
		$instance['gallery_grid_style']		= wp_kses_post( $new_instance['gallery_grid_style'] );
		$instance['captions_style']			= wp_kses_post( $new_instance['captions_style'] );
		$instance['category'] 			    = absint( $new_instance['category'] );
		$instance['gallery_color_scheme']   = wp_kses_post( $new_instance['gallery_color_scheme'] );
		$instance[ 'transparent_bg' ] 		= wp_kses_post( $new_instance[ 'transparent_bg' ] );
		$instance[ 'orderby' ] 				= wp_kses_post( $new_instance[ 'orderby' ] );
		$instance[ 'image_size' ] 			= wp_kses_post( $new_instance[ 'image_size' ] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {

		$title  			   = empty( $instance['title'] ) ? '' : $instance['title'];
		$page_id			   = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$gallery_button_text   = empty( $instance['gallery_button_text'] ) ? '' : $instance['gallery_button_text'];
		$gallery_rows_count    = empty( $instance['gallery_rows_count'] ) ? 2 : (int) $instance['gallery_rows_count'];
		$gallery_columns_count = empty( $instance['gallery_columns_count'] ) ? 3 : (int) $instance['gallery_columns_count'];
		$show_gallery_filters  = empty( $instance['show_gallery_filters'] ) ? 'yes' : $instance['show_gallery_filters'];
		$gallery_style 	   	   = empty( $instance['gallery_style'] ) ? 'wide' : $instance['gallery_style'];
		$gallery_grid_style	   = empty( $instance['gallery_grid_style'] ) ? 'fluid' : $instance['gallery_grid_style'];
		$captions_style		   = empty( $instance['captions_style'] ) ? 'default' : $instance['captions_style'];
		$category		   	   = empty( $instance['category'] ) ? '' : $instance['category'];
		$gallery_color_scheme  = empty( $instance['gallery_color_scheme'] ) ? 'dark' : $instance['gallery_color_scheme'];
		$transparent_bg  	   = empty( $instance['transparent_bg'] ) ? 'off' : 'on';
		$orderby  	  		   = empty( $instance['orderby'] ) ? 'none' : $instance['orderby'];
		$image_size  	  	   = empty( $instance['image_size'] ) ? 'default' : $instance['image_size'];
		
		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_style' ) ); ?>"><?php esc_html_e( 'Gallery Layout & Style', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr( $this->get_field_id('gallery_style') ); ?>" name="<?php echo esc_attr( $this->get_field_name('gallery_style') ); ?>" class="widefat" style="width:100%;">
			    <option value="style-1" <?php selected( $gallery_style, 'style-1' ); ?>><?php esc_html_e( 'Style 1: Wide layout, Fluid items', 'interico' ); ?></option>
			    <option value="style-2" <?php selected( $gallery_style, 'style-2' ); ?>><?php esc_html_e( 'Style 2: Boxed layout, Spaced items', 'interico' ); ?></option>
			    <option value="style-3" <?php selected( $gallery_style, 'style-3' ); ?>><?php esc_html_e( 'Style 3: Boxed layout, Cards', 'interico' ); ?></option>
			    <option value="style-4" <?php selected( $gallery_style, 'style-4' ); ?>><?php esc_html_e( 'Style 4: Boxed layout, Cards V2', 'interico' ); ?></option>
			    <option value="style-5" <?php selected( $gallery_style, 'style-5' ); ?>><?php esc_html_e( 'Style 5: Wide layout, Vertical items', 'interico' ); ?></option> 
			    <option value="style-6" <?php selected( $gallery_style, 'style-6' ); ?>><?php esc_html_e( 'Style 6: Wide layout, Spaced items', 'interico' ); ?></option>
			    <option value="style-7" <?php selected( $gallery_style, 'style-7' ); ?>><?php esc_html_e( 'Style 7: Wide layout, Cards', 'interico' ); ?></option>
			    <option value="style-8" <?php selected( $gallery_style, 'style-8' ); ?>><?php esc_html_e( 'Style 8: Wide layout, Cards V2', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_color_scheme' ) ); ?>"><?php esc_html_e( 'Gallery Color Scheme', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr(  $this->get_field_id('gallery_color_scheme') ); ?>" name="<?php echo esc_attr(  $this->get_field_name('gallery_color_scheme') ); ?>" class="widefat" style="width:100%;">
			    <option value="default" <?php selected( $gallery_color_scheme, 'default' ); ?>><?php esc_html_e( 'Default', 'interico' ); ?></option>
			    <option value="dark" <?php selected( $gallery_color_scheme, 'dark' ); ?>><?php esc_html_e( 'Dark', 'interico' ); ?></option> 
			    <option value="light" <?php selected( $gallery_color_scheme, 'light' ); ?>><?php esc_html_e( 'Light', 'interico' ); ?></option> 
			</select>
		</p>

		<p>
		    <input class="checkbox" type="checkbox" <?php checked( esc_attr( $transparent_bg ), 'on' ); ?> id="<?php echo esc_attr( $this->get_field_id( 'transparent_bg' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'transparent_bg' ) ); ?>" /> 
		    <label for="<?php echo esc_attr( $this->get_field_id( 'transparent_bg' ) ); ?>">Make background transparent</label>
		    <br><span style="color: #888";>Allows to use background color from widget or row settings.</span>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Set Title (Optional):', 'interico'  ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'show_gallery_filters' ) ); ?>"><?php esc_html_e( 'Show Gallery Filters', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr(  $this->get_field_id('show_gallery_filters') ); ?>" name="<?php echo esc_attr(  $this->get_field_name('show_gallery_filters') ); ?>" class="widefat" style="width:100%;">
			    <option value="yes" <?php selected( $show_gallery_filters, 'yes' ); ?>><?php esc_html_e( 'Yes', 'interico' ); ?></option>
			    <option value="no" <?php selected( $show_gallery_filters, 'no' ); ?>><?php esc_html_e( 'No', 'interico' ); ?></option> 
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_columns_count' ) ); ?>"><?php esc_html_e( 'Number of Columns', 'interico' ); ?>:</label> <br />
			<input type="radio" name="<?php echo esc_attr( $this->get_field_name( 'gallery_columns_count' ) ); ?>" value="2"><?php esc_html_e( '2 Columns', 'interico' ); ?><br>
			<input type="radio" name="<?php echo esc_attr( $this->get_field_name( 'gallery_columns_count' ) ); ?>" value="3"><?php esc_html_e( '3 Columns', 'interico' ); ?><br>
			<input type="radio" name="<?php echo esc_attr( $this->get_field_name( 'gallery_columns_count' ) ); ?>" value="4"><?php esc_html_e( '4 Columns', 'interico' ); ?><br>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_rows_count' ) ); ?>"><?php esc_html_e( 'Number of Rows', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_rows_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_rows_count' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_rows_count ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_button_text' ) ); ?>"><?php esc_html_e( 'Gallery Button Text', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_button_text ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Gallery Button Link:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_size' ) ); ?>"><?php esc_html_e( 'Image Size (Optional)', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr(  $this->get_field_id('image_size') ); ?>" name="<?php echo esc_attr(  $this->get_field_name('image_size') ); ?>" class="widefat" style="width:100%;">
			    <option value="default" <?php selected( $show_gallery_filters, 'default' ); ?>><?php esc_html_e( 'Default', 'interico' ); ?></option>
			    <option value="vertical" <?php selected( $show_gallery_filters, 'vertical' ); ?>><?php esc_html_e( 'Vertical', 'interico' ); ?></option> 
			</select>
			<span style="color:#888; margin-bottom: 7px;">Enable vertical image format instead of horizontal.</span>

		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Select Projects Category to Display:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_categories(
					array(
						'orderby' 		  => 'name',
						'post_type'       => 'portfolio', // filter by the post type 'portfolio'
						'taxonomy'        => 'portfolio_category',
						'value_field'	  => 'term_id',
						'selected' 		  => $category,
						'name'     		  => $this->get_field_name( 'category' ),
						'show_option_all' => esc_html__( 'All categories', 'interico'  ),
					)
				);
			?>

		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr(  $this->get_field_id('orderby') ); ?>" name="<?php echo esc_attr(  $this->get_field_name('orderby') ); ?>">
			    <option value="none" <?php selected( $orderby, 'none' ); ?>><?php esc_html_e( 'Default', 'interico' ); ?></option>
			    <option value="rand" <?php selected( $orderby, 'rand' ); ?>><?php esc_html_e( 'Random', 'interico' ); ?></option> 
			</select>
		</p>

		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {

		echo $args['before_widget'];

		// Set gallery filter button 'All projects' text
		$gallery_filter_button_text = get_theme_mod( 'tc_gallery_filter_button_text', 'All Projects' );

		// Set link text
		if ( isset( $instance['gallery_button_text'] ) ) {
			$gallery_button_text = $instance['gallery_button_text'];
		} else {
			$gallery_button_text = false;
		}

		// If set, use transparent background
		if ( isset( $instance['transparent_bg'] ) ) {
			$transparent_bg = $instance['transparent_bg'];
		} else {
			$transparent_bg = 'off';
		}
		
		// Set gallery color scheme
		if ( isset( $instance['gallery_color_scheme'] ) ) {
			$gallery_color_scheme = $instance['gallery_color_scheme'];
			if ( 'default' === $gallery_color_scheme ) {
				$gallery_color_scheme = get_theme_mod( 'tc_gallery_color_scheme' );
			}
		} else {
			$gallery_color_scheme = get_theme_mod( 'tc_gallery_color_scheme' );
		}

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Set rows count
		if ( isset( $instance['gallery_rows_count'] ) ) {
			$gallery_rows_count = $instance['gallery_rows_count'];
			if ( $gallery_rows_count === 0 ) {
				$gallery_rows_count = 2;
			}
		} else {
			$gallery_rows_count = 2;
		}

		// Set columns count
		if ( isset( $instance['gallery_columns_count'] ) ) {
			$gallery_columns_count = $instance['gallery_columns_count'];
			if ( $gallery_columns_count === 0 ) {
				$gallery_columns_count = 3;
			}
		} else {
			$gallery_columns_count = 3;
		}

		$gallery_column_width = 12/$gallery_columns_count;

		$gallery_items_count = $gallery_rows_count*$gallery_columns_count;

		// Set filters visibility
		if ( isset( $instance['show_gallery_filters'] ) ) {
			$show_gallery_filters = $instance['show_gallery_filters'];
		} else {
			$show_gallery_filters = 'yes';
		}

		// Set layout and grid style
		if ( isset( $instance['gallery_style'] ) ) {
			$gallery_style = $instance['gallery_style'];
		} else {
			$gallery_style = 'style-1';
		}

		if ( 'style-1' === $gallery_style || 'style-5' === $gallery_style ) {
			$gallery_layout = 'wide';
			$gallery_grid_style = 'fluid';
		} else {
			$gallery_layout = 'boxed';
			$gallery_grid_style = 'spaced';
		}

		if ( 'style-6' === $gallery_style || 'style-7' === $gallery_style || 'style-8' === $gallery_style ) {
			$gallery_layout = 'wide';
			$gallery_grid_style = 'spaced not-full';
		}

		// Set captions style
		if ( 'style-3' === $gallery_style || 'style-7' === $gallery_style ) {
			$gallery_captions_style = 'cards';
		} elseif ( 'style-4' === $gallery_style || 'style-8' === $gallery_style  ) {
			$gallery_captions_style = 'cards' . ' cards-flat';
		} else {
			$gallery_captions_style = 'default';
		}

		if ( isset( $instance['image_size'] ) ) {
			$image_size = $instance['image_size'];
		} else {
			$image_size = 'default';
		}

		// Filter by gallery category
		if ( isset( $instance['category'] ) ) {
			$category = $instance['category'];
		} else {
			$category = 0;
		}

		if ( isset( $instance['orderby'] ) ) {
			$orderby = $instance['orderby'];
		} else {
			$orderby = 'none';
		}

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );
		
		if ( $category === 0 ) {
			$projects_query = new WP_Query(
			array(
				'post_type' => 'portfolio',
				'posts_per_page' => $gallery_items_count,
				'orderby'        => $orderby,
				)
			);
		} else {
			$projects_query = new WP_Query(
				array(
					'post_type' => 'portfolio',
					'posts_per_page' => $gallery_items_count,
					'orderby'        => $orderby,
					'tax_query' => array(
						array(
					        'taxonomy' => 'portfolio_category',
					        'field'    => 'term_id',
					        'terms'    => $category,
						    )
						)

					)
				);
		}

		?>

		<!-- Begin Latest Projects -->
		<section class="section-gallery gallery-layout-<?php echo esc_attr( $gallery_layout ); echo ' ' . 'grid-' . esc_attr( $gallery_grid_style ); echo ' ' . 'captions-' . esc_attr( $gallery_captions_style ); echo ' ' . 'gallery-' . esc_attr( $gallery_color_scheme ); echo 'on' === esc_attr( $transparent_bg ) ? ' ' . 'transparent-bg' : ''; ?>">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<div class="latest-projects">
							<?php if( esc_attr( $instance['title'] ) ) : ?>
								<h2 class="section-title"><?php echo esc_attr( $instance['title'] ); ?></h2>
							<?php endif; ?>
							<?php if ( 'yes' === $show_gallery_filters ) : ?>
								<div class="gallery-categories normal">
									<ul id="filters">
									    <li><a href="#" data-filter="*" class="selected"><?php printf( esc_html__( '%s', 'interico' ), $gallery_filter_button_text ); ?></a></li>
										<?php 
											$terms = get_terms( 'portfolio_category' ); // get all categories (terms)
											$count = count( $terms ); // How many terms?
											if ( $count > 0 ){  // If there are more than 0 terms
												foreach ( $terms as $term ) {  // for each term:
													echo "<li><a href='#' data-filter='.".esc_attr( $term->slug )."'>".esc_attr( $term->name )."</a></li>\n";
													//create a list item with the current term slug for sorting, and name for label
												}
											}
										?>
									</ul>
								</div>	
							<?php endif; ?>			
						</div>
					</div>
				</div>
			</div>

			<?php if ( 'boxed' !== $gallery_layout ) : ?>
				<div id="gallery">
			<?php endif; ?>

				<div class="container<?php echo 'boxed' !== $gallery_layout ? '-fluid' : '' ?>">
					<div class="row<?php echo 'fluid' === $gallery_grid_style ? ' no-gutter' : '' ?>">

						<?php if ( 'boxed' === $gallery_layout ): ?>
							<div id="gallery">
						<?php endif; ?>
					

						<!-- Display the projects -->
						<?php
							if ( $projects_query->have_posts() ) :
								while ( $projects_query->have_posts() ) : $projects_query->the_post();
								
								$project_id = get_the_ID();
								$project = (array)get_post( $project_id );

								// Prepare Featured Image srcset
								$project_image_id   = get_post_thumbnail_id();

								// Define thumbnail sizes based on chosen layout
								if ( 'style-5' === $gallery_style || 'style-7' === $gallery_style || 'style-8' === $gallery_style || 'vertical' === $image_size ) {
									$project_image_data = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-vertical-s' );
									$sizes 		  		= array( 'interico-portfolio-vertical-l' );
								} else {
									$project_image_data = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-m' );
									$sizes 		  		= array( 'interico-portfolio-xs', 'interico-portfolio-s', 'interico-portfolio-ml', 'interico-portfolio-l', 'interico-portfolio-xl' );
								}

								$project['srcset']		= interico_img_sizes( $project_image_id, $sizes );
								$project['image_url'] 	= $project_image_data[0];

								$termsArray = get_the_terms( $project['ID'], 'portfolio_category' );  // Get the terms for this particular item
								$termsString = ""; // initialize the string that will contain the terms
								foreach ( $termsArray as $term ) { // for each term:
									$termsString .= $term->slug . ' '; // create a string that has all the slugs 
								}
						?>
						
							<!-- Begin project item -->
							<div class="col-xs-12 col-sm-6 col-lg-<?php echo esc_attr( $gallery_column_width ); ?> item <?php echo esc_attr( $termsString ); ?>">
								<a href="<?php esc_url( the_permalink() ); ?>" class="portfolio-box">
									<div class="image-container">
										<img src="<?php echo esc_url( $project['image_url'] ); ?>" srcset="<?php echo esc_html( $project['srcset'] ); ?>" width="<?php echo esc_attr( $project_image_data[1] ); ?>" height="<?php echo esc_attr(  $project_image_data[2] ); ?>" sizes="(min-width: 781px) 480px, calc(100vw - 30px)" alt="<?php echo esc_attr( $project['post_title'] ); ?>">
									</div>
									<div class="portfolio-box-caption">
										<div class="portfolio-box-caption-content">
											<div class="project-category text-faded">
												<?php echo esc_attr( $termsString ); ?>
											</div>
											<div class="project-name">
												<?php echo esc_attr( $project['post_title'] ); ?>
											</div>
										</div>
									</div>
								</a>
							</div> <!-- End project item -->
						
							<?php endwhile;	
							wp_reset_postdata();

						endif; ?>

					</div> <!-- End row -->
				</div> <!-- End container -->
			</div> <!-- End #gallery -->

			<?php if( esc_attr( $instance['gallery_button_text'] ) ) : ?>
				<a href="<?php echo esc_url( $page['url'] ); ?>" class="btn-all-projects"><?php printf( esc_html__( '%s', 'interico' ), $gallery_button_text ); ?></a>
			<?php endif; ?>		
		</section> <!-- End Content section -->    

		<?php
		echo $args['after_widget'];
	}

}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Projects_Gallery" );' ) );