<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Testimonial_Box extends WP_Widget {
	
	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Testimonial box', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Display Single Testimonial', 'interico' ) // Description
			)
		);	
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/

	function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['page_id']			= absint( $new_instance['page_id'] );
		$instance['testimonial_layout']	= wp_kses_post( $new_instance['testimonial_layout'] );
		$instance['testimonials_style']	= wp_kses_post( $new_instance['testimonials_style'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	function form( $instance ) {
		$page_id  			= empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$testimonial_layout = empty( $instance['testimonial_layout'] ) ? '' : $instance['testimonial_layout'];
		$testimonials_style = empty( $instance['testimonials_style'] ) ? '' : $instance['testimonials_style'];

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Select Testimonial to Display:', 'interico' ); ?></label>
			<?php
				wp_dropdown_pages( array(
					'selected'  => $page_id,
					'post_type' => 'testimonial',
					'id'        => $this->get_field_id( 'page_id' ),
					'name'      => $this->get_field_name( 'page_id' ),
				));
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonial_layout' ) ); ?>"><?php esc_html_e( 'Select Icon Box Layout:', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'testimonial_layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'testimonial_layout' ) ); ?>">
				<option value="left" <?php selected( $testimonial_layout, 'left' ); ?>><?php esc_html_e( 'Profile Inside', 'interico' ); ?></option>
				<option value="bottom" <?php selected( $testimonial_layout, 'bottom' ); ?>><?php esc_html_e( 'Profile Bottom Center', 'interico' ); ?></option>
				<option value="bottom-overlapped" <?php selected( $testimonial_layout, 'bottom-overlapped' ); ?>><?php esc_html_e( 'Profile Bottom Center Overlapped', 'interico' ); ?></option>
				<option value="bottom-left" <?php selected( $testimonial_layout, 'bottom-left' ); ?>><?php esc_html_e( 'Profile Bottom Left', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'testimonials_style' ) ); ?>"><?php esc_html_e( 'Color Scheme', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr( $this->get_field_id('testimonials_style') ); ?>" name="<?php echo esc_attr( $this->get_field_name('testimonials_style') ); ?>" class="widefat" style="width:100%;">
			    <option value="light" <?php selected( $testimonials_style, 'light' ); ?>><?php esc_html_e( 'Style 1: Light box', 'interico' ); ?></option>
			    <option value="dark" <?php selected( $testimonials_style, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark box', 'interico' ); ?></option>
			</select>
		</p>

		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	function widget( $args, $instance ) {

		echo $args['before_widget'];

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );

		// Prepare Featured Image srcset
		$page_image_id         = get_post_thumbnail_id( $page_id );
		$page_image_data       = wp_get_attachment_image_src( $page_image_id );
		$page['image_url']     = $page_image_data[0];

		if ( class_exists('acf') ) {
			$testimonial_subtitle = get_field( 'testimonial_subtitle', $page_id );
			$testimonial_headline = get_field( 'testimonial_headline', $page_id );
		}

		// Set testimonial layout
		if ( isset( $instance['testimonial_layout'] ) ) {
			$testimonial_layout = $instance['testimonial_layout'];
		} else {
			$testimonial_layout = 'left';
		}

		// Testimonial title
		if ( isset( $page['post_title'] ) ) {
			$post_title = $page['post_title'];
		} else {
			$post_title = false;
		}

		// Set testimonial style
		if ( isset( $instance['testimonials_style'] ) ) {
			$testimonials_style = $instance['testimonials_style'];
		} else {
			$testimonials_style = 'light';
		}

		// Testimonial content
		if ( isset( $page['post_content'] ) ) {
			$post_content = $page['post_content'];
		} else {
			$post_content = false;
		}
		
		?>

		<!-- Begin Testimonial -->
		<?php if ( esc_attr( $post_content ) ) : ?>
			<div class="testimonial image-<?php echo esc_attr( $testimonial_layout); ?> testimonial-<?php echo esc_attr( $testimonials_style ); ?>">
				<div class="content-box">
					<div class="content-box-info">
						<?php if ( 'left' === $testimonial_layout ) : ?>
							<div class="profile">
								<?php if ( esc_attr( $post_title ) ) : ?>
									<img src="<?php echo esc_url( $page['image_url'] ); ?>" alt="<?php echo esc_attr( $post_title ); ?>">
									<p class="name"><?php echo esc_attr( $post_title ); ?></p>
								<?php endif; ?>
								<?php if ( class_exists('acf') && ! empty( $testimonial_subtitle ) ) : ?>
									<p class="company"><?php echo esc_attr( $testimonial_subtitle ); ?></p>
								<?php endif; ?>
							</div>
						<?php endif; ?>
						
							<div class="testimonial-content">
								<?php if ( class_exists('acf') && ! empty( $testimonial_headline ) ) : ?>
									<p class="testimonial-headline"><?php echo esc_attr( $testimonial_headline ); ?></p>
								<?php endif; ?>
								<p><?php echo esc_html( $post_content ); ?></p>
							</div>
					</div>
				</div>
				<?php if ( 'left' !== $testimonial_layout ) : ?>
					<div class="profile">
						<?php if ( esc_attr( $post_title ) ) : ?>
							<img src="<?php echo esc_url( $page['image_url'] ); ?>" alt="<?php echo esc_attr( $post_title ); ?>">
							<p class="name"><?php echo esc_attr( $post_title ); ?></p>
						<?php endif; ?>
						<?php if ( class_exists('acf') && ! empty( $testimonial_subtitle ) ) : ?>
							<p class="company"><?php echo esc_attr( $testimonial_subtitle ); ?></p>
						<?php endif; ?>
					</div>
				<?php endif; ?>
			</div> 
		<?php endif; ?>	
		<!-- End Testimonial -->
		
		<?php

		echo $args['after_widget'];
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Testimonial_Box" );' ) );
